@@ -7,7 +7,7 @@
 -- |
 --  Module      :  GraphMatch
 --  Copyright   :  (c) 2003, Graham Klyne, 2009 Vasili I Galchin,
---                 2011, 2012, 2016, 2018, 2020 Douglas Burke
+--                 2011, 2012, 2016, 2018, 2020, 2022 Douglas Burke
 --  License     :  GPL V2
 --
 --  Maintainer  :  Douglas Burke
@@ -188,8 +188,8 @@ makeScopedArc :: (Label lb) => Int -> Arc lb -> Arc (ScopedLabel lb)
 makeScopedArc scope = fmap (ScopedLabel scope)
 
 instance (Label lb) => Label (ScopedLabel lb) where
-    getLocal  lab    = error $ "getLocal for ScopedLabel: "++show lab
-    makeLabel locnam = error $ "makeLabel for ScopedLabel: "++locnam
+    getLocal  lab    = error $ "getLocal for ScopedLabel: " ++ show lab
+    makeLabel locnam = error $ "makeLabel for ScopedLabel: " ++ locnam
     labelIsVar (ScopedLabel _ lab)   = labelIsVar lab
     labelHash seed (ScopedLabel scope lab)
         | labelIsVar lab    = seed `hashWithSalt` scope
@@ -396,7 +396,7 @@ graphMatch2 matchable gs1 gs2 lmap ((ec1@(ev1,ls1),ec2@(ev2,ls2)):ecpairs) =
         --  NOTE:  final test is call of external matchable function
         glp = [ (l1,l2) | l1 <- ls1 , l2 <- ls2 , matchable l1 l2 ]
     in
-        assert (ev1==ev2) -- "GraphMatch2: Equivalence class value mismatch" $
+        assert (ev1 == ev2) -- "GraphMatch2: Equivalence class value mismatch" $
         $ try glp
 
 -- this was in Swish.Utils.MiscHelpers along with a simple hash-based function
@@ -410,8 +410,8 @@ hashModulus = 16000001
 --
 showLabelMap :: (Label lb) => LabelMap lb -> String
 showLabelMap (LabelMap gn lmap) =
-    "LabelMap gen="++ Prelude.show gn ++", map="++
-    foldl' (++) "" (map (("\n    "++) . Prelude.show) es)
+    "LabelMap gen=" ++ Prelude.show gn ++ ", map=" ++
+    foldl' (++) "" (map (("\n    " ++) . Prelude.show) es)
     where
         es = M.toList lmap
 
@@ -454,7 +454,7 @@ setLabelHash  (LabelMap g lmap) (lb,lh) =
 --  but with an incremented generation number.
 --
 newGenerationMap :: (Label lb) => LabelMap lb -> LabelMap lb
-newGenerationMap (LabelMap g lvs) = LabelMap (g+1) lvs
+newGenerationMap (LabelMap g lvs) = LabelMap (g + 1) lvs
 
 -- | Scan label list, assigning initial label map values,
 --  adding new values to the label map supplied.
@@ -537,7 +537,7 @@ reclassify ::
   --     then `True`, otherwise `False`.
 
 reclassify gs1 gs2 lmap@(LabelMap _ lm) ecpairs =
-    assert (gen1==gen2) -- "Label map generation mismatch"
+    assert (gen1 == gen2) -- "Label map generation mismatch"
       (LabelMap gen1 lm',ecpairs',newPart,matchPart)
     where
         LabelMap gen1 lm1 =
@@ -580,13 +580,13 @@ remapLabels ::
 remapLabels gs lmap@(LabelMap gen _) ls =
     LabelMap gen' $ M.fromList newEntries
     where
-        gen'                = gen+1
+        gen'                = gen + 1
         newEntries          = [ (l, (gen', fromIntegral (newIndex l))) | l <- ls ]
         -- TODO: should review this given the changes to the hash code
         --       since it was re-written
         newIndex l
-            | labelIsVar l  = mapAdjacent l                 -- adjacency classifies variable labels
-            | otherwise     = fromIntegral $ hashVal gen l  -- otherwise rehash (to disentangle collisions)
+            | labelIsVar l  = mapAdjacent l    -- adjacency classifies variable labels
+            | otherwise     = hashVal gen l    -- otherwise rehash (to disentangle collisions)  TODO: BRANCH IS UNTESTED
 
         -- mapAdjacent used to use `rem` hashModulus
         mapAdjacent l       = hashModulus `hashWithSalt` sum (sigsOver l)
