@@ -1,14 +1,20 @@
+{-# LANGUAGE CPP #-}
+
+#if (__GLASGOW_HASKELL__ >= 802)
+{-# LANGUAGE DerivingStrategies #-}
+#endif
+
 --------------------------------------------------------------------------------
 --  See end of this file for licence information.
 --------------------------------------------------------------------------------
 -- |
 --  Module      :  GraphPartition
---  Copyright   :  (c) 2003, Graham Klyne, 2009 Vasili I Galchin, 2011, 2012 Douglas Burke
+--  Copyright   :  (c) 2003, Graham Klyne, 2009 Vasili I Galchin, 2011, 2012, 2022 Douglas Burke
 --  License     :  GPL V2
 --
 --  Maintainer  :  Douglas Burke
 --  Stability   :  experimental
---  Portability :  H98
+--  Portability :  CPP, DerivingStrategies
 --
 --  This module contains functions for partitioning a graph into subgraphs
 --  that rooted from different subject nodes.
@@ -50,7 +56,11 @@ import qualified Data.List.NonEmpty as NE
 --    'PartObj' constructors.
 
 data PartitionedGraph lb = PartitionedGraph [GraphPartition lb]
-    deriving (Eq, Show)
+    deriving
+#if (__GLASGOW_HASKELL__ >= 802)
+      stock
+#endif
+      (Eq, Show)
 
 -- | Returns all the arcs in the partitioned graph.
 getArcs :: PartitionedGraph lb -> [Arc lb]
@@ -104,7 +114,7 @@ instance (Label lb) => Show (GraphPartition lb) where
 partitionShow :: (Label lb) => GraphPartition lb -> String
 partitionShow (PartObj ob)             = show ob
 partitionShow (PartSub sb (pr :| prs)) =
-    "("++ show sb ++ " " ++ showpr pr ++ concatMap ((" ; "++).showpr) prs ++ ")"
+    "(" ++ show sb ++ " " ++ showpr pr ++ concatMap ((" ; " ++).showpr) prs ++ ")"
     where
         showpr (a,b) = show a ++ " " ++ show b
 
@@ -118,9 +128,9 @@ partitionShowP ::
     -> String
 partitionShowP _    (PartObj ob)             = show ob
 partitionShowP pref (PartSub sb (pr :| prs)) =
-    pref++"("++ show sb ++ " " ++ showpr pr ++ concatMap (((pref++"  ; ")++).showpr) prs ++ ")"
+    pref ++ "(" ++ show sb ++ " " ++ showpr pr ++ concatMap (((pref ++ "  ; ") ++ ).showpr) prs ++ ")"
     where
-        showpr (a,b) = show a ++ " " ++ partitionShowP (pref++"  ") b
+        showpr (a,b) = show a ++ " " ++ partitionShowP (pref ++ "  ") b
 
 ------------------------------------------------------------
 --  Creating partitioned graphs
@@ -213,7 +223,7 @@ makePartitions1 [] = do
 makePartitions1 (sub:subs) = do
     ph <- makePartitions2 sub
     pt <- makePartitions1 subs
-    return $ ph++pt
+    return $ ph ++ pt
 
 makePartitions2 :: 
     (Eq lb) =>
@@ -265,7 +275,7 @@ pickIntSubject :: (Eq lb) =>
     -> PState lb [LabelledArcs lb]
 pickIntSubject sub = do
     (s1,s2,s3) <- get
-    let varsub = removeBy (\x->(x==).fst) sub s3
+    let varsub = removeBy (\x -> (x ==).fst) sub s3
     case varsub of
         Just (vs, s3new) -> put (s1,s2,s3new) >> return [vs]
         Nothing          -> return []
@@ -276,7 +286,7 @@ pickVarSubject ::
     PState lb [LabelledArcs lb]
 pickVarSubject sub = do
     (s1,s2,s3) <- get
-    let varsub = removeBy (\x->(x==).fst) sub s2
+    let varsub = removeBy (\x -> (x ==).fst) sub s2
     case varsub of
         Just (vs, s2new) -> put (s1,s2new,s3) >> return [vs]
         _                -> return []
@@ -551,7 +561,7 @@ listDifferences cmp (a1:a1t) a2s =
         comps = [ (cmp a1 a2,a2t) | (a2,a2t) <- removeEach a2s ]
         maybeResult (Nothing,_)   = Nothing
         maybeResult (Just ds,a2t) = Just (ds,a2t)
-        morediffs xds xa1h xa1t xa2t  = (xds++xds1,xa1h++xa1r,xa2r)
+        morediffs xds xa1h xa1t xa2t  = (xds ++ xds1, xa1h ++ xa1r, xa2r)
             where
                 (xds1,xa1r,xa2r) = listDifferences cmp xa1t xa2t
         choose  []       = Nothing
@@ -575,7 +585,7 @@ testdiff2 = testdiff1 == ([((12,15),(13,15)),((5,8),(6,9))],[(1,2)],[(0,1)])
 --------------------------------------------------------------------------------
 --
 --  Copyright (c) 2003, Graham Klyne, 2009 Vasili I Galchin,
---    2011, 2012 Douglas Burke
+--    2011, 2012, 2022 Douglas Burke
 --  All rights reserved.
 --
 --  This file is part of Swish.
