@@ -1,18 +1,22 @@
 {-# LANGUAGE CPP #-}
 {-# LANGUAGE OverloadedStrings #-}
 
+#if (__GLASGOW_HASKELL__ >= 802)
+{-# LANGUAGE DerivingStrategies #-}
+#endif
+
 --------------------------------------------------------------------------------
 --  See end of this file for licence information.
 --------------------------------------------------------------------------------
 -- |
 --  Module      :  Internal
 --  Copyright   :  (c) 2003, Graham Klyne, 2009 Vasili I Galchin,
---                 2011, 2012, 2013, 2014, 2016, 2018, 2020 Douglas Burke
+--                 2011, 2012, 2013, 2014, 2016, 2018, 2020, 2022 Douglas Burke
 --  License     :  GPL V2
 --
 --  Maintainer  :  Douglas Burke
 --  Stability   :  experimental
---  Portability :  CPP, OverloadedStrings
+--  Portability :  CPP, DerivingStrategies, OverloadedStrings
 --
 --  Utility routines.
 --
@@ -122,7 +126,11 @@ type PredTree lb = [(lb,[lb])]
 -- | The context for label creation.
 --
 data LabelContext = SubjContext | PredContext | ObjContext
-                    deriving (Eq, Show)
+                    deriving
+#if (__GLASGOW_HASKELL__ >= 802)
+                      stock
+#endif
+                      (Eq, Show)
 
 -- | A generator for BNode labels.
 data NodeGenState = Ngs
@@ -405,7 +413,7 @@ quoteText txt =
       n = if has3Q || (not hasNL && not hasSQ) then 1 else 3
             
       qch = B.fromString (replicate n '"')
-      qst = B.fromText $ quoteT (n==1) txt
+      qst = B.fromText $ quoteT (n == 1) txt
 
   in mconcat [qch, qst, qch]
 
@@ -701,7 +709,7 @@ extractList_ subjs props setSubjs setProps lctxt ln = do
 --------------------------------------------------------------------------------
 --
 --  Copyright (c) 2003, Graham Klyne, 2009 Vasili I Galchin,
---    2011, 2012, 2013, 2014, 2016, 2018, 2020 Douglas Burke
+--    2011, 2012, 2013, 2014, 2016, 2018, 2020, 2022 Douglas Burke
 --  All rights reserved.
 --
 --  This file is part of Swish.
